/****************************************************************************
** Meta object code from reading C++ file 'qlearnframe.hpp'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../seq66-0.99.26/seq_qt5/src/gui/qlearnframe.hpp"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qlearnframe.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_seq66__qlearnframe_t {
    QByteArrayData data[15];
    char stringdata0[188];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_seq66__qlearnframe_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_seq66__qlearnframe_t qt_meta_stringdata_seq66__qlearnframe = {
    {
QT_MOC_LITERAL(0, 0, 18), // "seq66::qlearnframe"
QT_MOC_LITERAL(1, 19, 16), // "slot_poll_update"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 20), // "slot_select_category"
QT_MOC_LITERAL(4, 58, 8), // "buttonno"
QT_MOC_LITERAL(5, 67, 18), // "slot_select_action"
QT_MOC_LITERAL(6, 86, 11), // "slot_cancel"
QT_MOC_LITERAL(7, 98, 9), // "slot_save"
QT_MOC_LITERAL(8, 108, 10), // "slot_reset"
QT_MOC_LITERAL(9, 119, 10), // "slot_clear"
QT_MOC_LITERAL(10, 130, 14), // "slot_clear_all"
QT_MOC_LITERAL(11, 145, 7), // "slot_ok"
QT_MOC_LITERAL(12, 153, 12), // "slot_inverse"
QT_MOC_LITERAL(13, 166, 10), // "slot_d1min"
QT_MOC_LITERAL(14, 177, 10) // "slot_d1max"

    },
    "seq66::qlearnframe\0slot_poll_update\0"
    "\0slot_select_category\0buttonno\0"
    "slot_select_action\0slot_cancel\0slot_save\0"
    "slot_reset\0slot_clear\0slot_clear_all\0"
    "slot_ok\0slot_inverse\0slot_d1min\0"
    "slot_d1max"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_seq66__qlearnframe[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x08 /* Private */,
       3,    1,   75,    2, 0x08 /* Private */,
       5,    1,   78,    2, 0x08 /* Private */,
       6,    0,   81,    2, 0x08 /* Private */,
       7,    0,   82,    2, 0x08 /* Private */,
       8,    0,   83,    2, 0x08 /* Private */,
       9,    0,   84,    2, 0x08 /* Private */,
      10,    0,   85,    2, 0x08 /* Private */,
      11,    0,   86,    2, 0x08 /* Private */,
      12,    0,   87,    2, 0x08 /* Private */,
      13,    0,   88,    2, 0x08 /* Private */,
      14,    0,   89,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void seq66::qlearnframe::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<qlearnframe *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slot_poll_update(); break;
        case 1: _t->slot_select_category((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->slot_select_action((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->slot_cancel(); break;
        case 4: _t->slot_save(); break;
        case 5: _t->slot_reset(); break;
        case 6: _t->slot_clear(); break;
        case 7: _t->slot_clear_all(); break;
        case 8: _t->slot_ok(); break;
        case 9: _t->slot_inverse(); break;
        case 10: _t->slot_d1min(); break;
        case 11: _t->slot_d1max(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject seq66::qlearnframe::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_seq66__qlearnframe.data,
    qt_meta_data_seq66__qlearnframe,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *seq66::qlearnframe::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *seq66::qlearnframe::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_seq66__qlearnframe.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "performer::callbacks"))
        return static_cast< performer::callbacks*>(this);
    return QFrame::qt_metacast(_clname);
}

int seq66::qlearnframe::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
