/********************************************************************************
** Form generated from reading UI file 'qsessionframe.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSESSIONFRAME_H
#define UI_QSESSIONFRAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>

QT_BEGIN_NAMESPACE

class Ui_qsessionframe
{
public:
    QLabel *sessionNameLabel;
    QTextEdit *sessionNameText;
    QLabel *sessionServerUrl;
    QTextEdit *sessionUrlText;
    QLabel *sessionLogLabel;
    QPushButton *pushButtonReload;
    QTextEdit *sessionManagerNameText;
    QLabel *sessionManagerNameLabel;
    QLabel *displayNameLabel;
    QLabel *clientIdLabel;
    QTextEdit *displayNameText;
    QTextEdit *clientIdText;
    QLineEdit *songPathText;
    QLabel *label;
    QComboBox *macroComboBox;
    QCheckBox *checkBoxMacrosActive;
    QLineEdit *lineEditLogFile;
    QPlainTextEdit *plainTextSongInfo;
    QLabel *labelTrackInfo;
    QLabel *label_3;
    QLabel *labelCharsRemaining;
    QLabel *labelCharactersRemaining;
    QPushButton *pushButtonSaveInfo;
    QSpinBox *spinBoxTrackNumber;
    QLabel *label_2;
    QLineEdit *lineEditLastUsedDir;
    QLabel *label_4;
    QLabel *label_5;
    QPushButton *pushButtonLogFileClear;

    void setupUi(QFrame *qsessionframe)
    {
        if (qsessionframe->objectName().isEmpty())
            qsessionframe->setObjectName(QString::fromUtf8("qsessionframe"));
        qsessionframe->resize(690, 460);
        sessionNameLabel = new QLabel(qsessionframe);
        sessionNameLabel->setObjectName(QString::fromUtf8("sessionNameLabel"));
        sessionNameLabel->setGeometry(QRect(17, 42, 149, 18));
        sessionNameLabel->setMinimumSize(QSize(100, 0));
        QFont font;
        font.setPointSize(11);
        font.setBold(true);
        sessionNameLabel->setFont(font);
        sessionNameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        sessionNameText = new QTextEdit(qsessionframe);
        sessionNameText->setObjectName(QString::fromUtf8("sessionNameText"));
        sessionNameText->setEnabled(false);
        sessionNameText->setGeometry(QRect(189, 38, 480, 28));
        sessionNameText->setMinimumSize(QSize(420, 28));
        sessionNameText->setMaximumSize(QSize(480, 28));
        QFont font1;
        font1.setPointSize(11);
        sessionNameText->setFont(font1);
        sessionNameText->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        sessionNameText->setUndoRedoEnabled(false);
        sessionNameText->setReadOnly(true);
        sessionServerUrl = new QLabel(qsessionframe);
        sessionServerUrl->setObjectName(QString::fromUtf8("sessionServerUrl"));
        sessionServerUrl->setGeometry(QRect(29, 72, 137, 18));
        sessionServerUrl->setMinimumSize(QSize(132, 18));
        sessionServerUrl->setFont(font);
        sessionServerUrl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        sessionUrlText = new QTextEdit(qsessionframe);
        sessionUrlText->setObjectName(QString::fromUtf8("sessionUrlText"));
        sessionUrlText->setEnabled(false);
        sessionUrlText->setGeometry(QRect(189, 68, 480, 28));
        sessionUrlText->setMinimumSize(QSize(420, 28));
        sessionUrlText->setMaximumSize(QSize(480, 30));
        sessionUrlText->setFont(font1);
        sessionUrlText->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        sessionUrlText->setUndoRedoEnabled(false);
        sessionUrlText->setReadOnly(true);
        sessionLogLabel = new QLabel(qsessionframe);
        sessionLogLabel->setObjectName(QString::fromUtf8("sessionLogLabel"));
        sessionLogLabel->setGeometry(QRect(21, 158, 145, 32));
        sessionLogLabel->setMinimumSize(QSize(80, 32));
        sessionLogLabel->setFont(font);
        sessionLogLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        pushButtonReload = new QPushButton(qsessionframe);
        pushButtonReload->setObjectName(QString::fromUtf8("pushButtonReload"));
        pushButtonReload->setEnabled(false);
        pushButtonReload->setGeometry(QRect(559, 340, 100, 32));
        pushButtonReload->setMinimumSize(QSize(100, 32));
        pushButtonReload->setMaximumSize(QSize(16777215, 40));
        pushButtonReload->setFont(font1);
        sessionManagerNameText = new QTextEdit(qsessionframe);
        sessionManagerNameText->setObjectName(QString::fromUtf8("sessionManagerNameText"));
        sessionManagerNameText->setEnabled(false);
        sessionManagerNameText->setGeometry(QRect(189, 8, 480, 28));
        sessionManagerNameText->setMinimumSize(QSize(420, 24));
        sessionManagerNameText->setMaximumSize(QSize(480, 30));
        sessionManagerNameText->setFont(font1);
        sessionManagerNameText->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        sessionManagerNameText->setUndoRedoEnabled(false);
        sessionManagerNameText->setReadOnly(true);
        sessionManagerNameLabel = new QLabel(qsessionframe);
        sessionManagerNameLabel->setObjectName(QString::fromUtf8("sessionManagerNameLabel"));
        sessionManagerNameLabel->setGeometry(QRect(9, 10, 161, 18));
        sessionManagerNameLabel->setFont(font);
        sessionManagerNameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        displayNameLabel = new QLabel(qsessionframe);
        displayNameLabel->setObjectName(QString::fromUtf8("displayNameLabel"));
        displayNameLabel->setGeometry(QRect(21, 102, 145, 18));
        displayNameLabel->setFont(font);
        displayNameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        clientIdLabel = new QLabel(qsessionframe);
        clientIdLabel->setObjectName(QString::fromUtf8("clientIdLabel"));
        clientIdLabel->setGeometry(QRect(373, 102, 125, 18));
        clientIdLabel->setFont(font);
        clientIdLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        displayNameText = new QTextEdit(qsessionframe);
        displayNameText->setObjectName(QString::fromUtf8("displayNameText"));
        displayNameText->setEnabled(false);
        displayNameText->setGeometry(QRect(189, 98, 160, 28));
        displayNameText->setMinimumSize(QSize(0, 28));
        displayNameText->setMaximumSize(QSize(16777215, 30));
        displayNameText->setFont(font1);
        displayNameText->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        displayNameText->setUndoRedoEnabled(false);
        displayNameText->setReadOnly(true);
        clientIdText = new QTextEdit(qsessionframe);
        clientIdText->setObjectName(QString::fromUtf8("clientIdText"));
        clientIdText->setEnabled(false);
        clientIdText->setGeometry(QRect(513, 98, 156, 28));
        clientIdText->setMinimumSize(QSize(0, 28));
        clientIdText->setMaximumSize(QSize(16777215, 30));
        clientIdText->setFont(font1);
        clientIdText->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        clientIdText->setUndoRedoEnabled(false);
        clientIdText->setReadOnly(true);
        songPathText = new QLineEdit(qsessionframe);
        songPathText->setObjectName(QString::fromUtf8("songPathText"));
        songPathText->setEnabled(false);
        songPathText->setGeometry(QRect(179, 190, 480, 28));
        songPathText->setMinimumSize(QSize(0, 28));
        songPathText->setMaximumSize(QSize(16777215, 30));
        QFont font2;
        font2.setPointSize(11);
        font2.setItalic(true);
        songPathText->setFont(font2);
        songPathText->setToolTipDuration(-1);
        songPathText->setReadOnly(true);
        songPathText->setCursorMoveStyle(Qt::LogicalMoveStyle);
        label = new QLabel(qsessionframe);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(15, 130, 151, 20));
        label->setFont(font);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        macroComboBox = new QComboBox(qsessionframe);
        macroComboBox->setObjectName(QString::fromUtf8("macroComboBox"));
        macroComboBox->setGeometry(QRect(217, 130, 452, 24));
        macroComboBox->setMinimumSize(QSize(0, 24));
        macroComboBox->setFont(font1);
        macroComboBox->setInsertPolicy(QComboBox::InsertAlphabetically);
        checkBoxMacrosActive = new QCheckBox(qsessionframe);
        checkBoxMacrosActive->setObjectName(QString::fromUtf8("checkBoxMacrosActive"));
        checkBoxMacrosActive->setGeometry(QRect(189, 130, 21, 22));
        lineEditLogFile = new QLineEdit(qsessionframe);
        lineEditLogFile->setObjectName(QString::fromUtf8("lineEditLogFile"));
        lineEditLogFile->setGeometry(QRect(179, 160, 421, 28));
        lineEditLogFile->setMinimumSize(QSize(0, 28));
        lineEditLogFile->setFont(font1);
        lineEditLogFile->setClearButtonEnabled(false);
        plainTextSongInfo = new QPlainTextEdit(qsessionframe);
        plainTextSongInfo->setObjectName(QString::fromUtf8("plainTextSongInfo"));
        plainTextSongInfo->setGeometry(QRect(31, 280, 501, 91));
        plainTextSongInfo->setFont(font1);
        labelTrackInfo = new QLabel(qsessionframe);
        labelTrackInfo->setObjectName(QString::fromUtf8("labelTrackInfo"));
        labelTrackInfo->setGeometry(QRect(41, 260, 125, 17));
        labelTrackInfo->setFont(font);
        label_3 = new QLabel(qsessionframe);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(167, 260, 393, 17));
        label_3->setFont(font2);
        labelCharsRemaining = new QLabel(qsessionframe);
        labelCharsRemaining->setObjectName(QString::fromUtf8("labelCharsRemaining"));
        labelCharsRemaining->setGeometry(QRect(269, 380, 191, 22));
        labelCharsRemaining->setMinimumSize(QSize(0, 22));
        QFont font3;
        font3.setItalic(true);
        labelCharsRemaining->setFont(font3);
        labelCharsRemaining->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelCharactersRemaining = new QLabel(qsessionframe);
        labelCharactersRemaining->setObjectName(QString::fromUtf8("labelCharactersRemaining"));
        labelCharactersRemaining->setGeometry(QRect(479, 380, 71, 22));
        labelCharactersRemaining->setMinimumSize(QSize(0, 22));
        labelCharactersRemaining->setFont(font2);
        labelCharactersRemaining->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        pushButtonSaveInfo = new QPushButton(qsessionframe);
        pushButtonSaveInfo->setObjectName(QString::fromUtf8("pushButtonSaveInfo"));
        pushButtonSaveInfo->setGeometry(QRect(559, 280, 100, 32));
        pushButtonSaveInfo->setMinimumSize(QSize(100, 32));
        pushButtonSaveInfo->setMaximumSize(QSize(16777215, 40));
        pushButtonSaveInfo->setFont(font1);
        spinBoxTrackNumber = new QSpinBox(qsessionframe);
        spinBoxTrackNumber->setObjectName(QString::fromUtf8("spinBoxTrackNumber"));
        spinBoxTrackNumber->setGeometry(QRect(149, 380, 65, 26));
        spinBoxTrackNumber->setFont(font1);
        label_2 = new QLabel(qsessionframe);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(25, 220, 141, 22));
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lineEditLastUsedDir = new QLineEdit(qsessionframe);
        lineEditLastUsedDir->setObjectName(QString::fromUtf8("lineEditLastUsedDir"));
        lineEditLastUsedDir->setEnabled(false);
        lineEditLastUsedDir->setGeometry(QRect(179, 220, 480, 28));
        lineEditLastUsedDir->setMinimumSize(QSize(0, 28));
        lineEditLastUsedDir->setFont(font2);
        label_4 = new QLabel(qsessionframe);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(55, 194, 111, 22));
        label_4->setFont(font);
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_5 = new QLabel(qsessionframe);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setGeometry(QRect(29, 380, 131, 22));
        label_5->setFont(font);
        pushButtonLogFileClear = new QPushButton(qsessionframe);
        pushButtonLogFileClear->setObjectName(QString::fromUtf8("pushButtonLogFileClear"));
        pushButtonLogFileClear->setGeometry(QRect(603, 160, 56, 28));
        pushButtonLogFileClear->setMinimumSize(QSize(56, 0));
        pushButtonLogFileClear->setMaximumSize(QSize(56, 16777215));
        pushButtonLogFileClear->setFont(font1);
        QWidget::setTabOrder(sessionManagerNameText, sessionNameText);
        QWidget::setTabOrder(sessionNameText, sessionUrlText);
        QWidget::setTabOrder(sessionUrlText, displayNameText);
        QWidget::setTabOrder(displayNameText, clientIdText);
        QWidget::setTabOrder(clientIdText, macroComboBox);
        QWidget::setTabOrder(macroComboBox, pushButtonReload);
        QWidget::setTabOrder(pushButtonReload, songPathText);

        retranslateUi(qsessionframe);

        QMetaObject::connectSlotsByName(qsessionframe);
    } // setupUi

    void retranslateUi(QFrame *qsessionframe)
    {
        qsessionframe->setWindowTitle(QCoreApplication::translate("qsessionframe", "Frame", nullptr));
        sessionNameLabel->setText(QCoreApplication::translate("qsessionframe", "Session Path", nullptr));
        sessionNameText->setHtml(QCoreApplication::translate("qsessionframe", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'WenQuanYi Zen Hei'; font-size:10pt; font-weight:456;\">None</span></p></body></html>", nullptr));
        sessionServerUrl->setText(QCoreApplication::translate("qsessionframe", "Server URL", nullptr));
        sessionUrlText->setHtml(QCoreApplication::translate("qsessionframe", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'WenQuanYi Zen Hei'; font-size:10pt; font-weight:456;\">None</span></p></body></html>", nullptr));
        sessionLogLabel->setText(QCoreApplication::translate("qsessionframe", "Session Log File", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonReload->setToolTip(QCoreApplication::translate("qsessionframe", "Restarts the whole application, reloading any changed settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonReload->setText(QCoreApplication::translate("qsessionframe", "Restart", nullptr));
        sessionManagerNameText->setHtml(QCoreApplication::translate("qsessionframe", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'WenQuanYi Zen Hei'; font-size:10pt; font-weight:456;\">Normal</span></p></body></html>", nullptr));
        sessionManagerNameLabel->setText(QCoreApplication::translate("qsessionframe", "Session Manager", nullptr));
        displayNameLabel->setText(QCoreApplication::translate("qsessionframe", "Config File", nullptr));
        clientIdLabel->setText(QCoreApplication::translate("qsessionframe", "Client ID/UUID", nullptr));
        displayNameText->setHtml(QCoreApplication::translate("qsessionframe", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'WenQuanYi Zen Hei'; font-size:10pt; font-weight:456;\">None</span></p></body></html>", nullptr));
        clientIdText->setHtml(QCoreApplication::translate("qsessionframe", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'WenQuanYi Zen Hei'; font-size:10pt; font-weight:456;\">None</span></p></body></html>", nullptr));
        songPathText->setText(QCoreApplication::translate("qsessionframe", "Current Song Path", nullptr));
        label->setText(QCoreApplication::translate("qsessionframe", "Macro Execution", nullptr));
        macroComboBox->setCurrentText(QString());
        checkBoxMacrosActive->setText(QString());
#if QT_CONFIG(tooltip)
        lineEditLogFile->setToolTip(QCoreApplication::translate("qsessionframe", "Provides a log file to write Seq66 messages.\n"
"All console output is redirected to this file;\n"
"to see it in the console, click the \"X\" button to\n"
"remove this filename.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        plainTextSongInfo->setToolTip(QCoreApplication::translate("qsessionframe", "This text is stored as Meta Text in the first track.\n"
"It can include any comments desired, including\n"
"author and dates.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelTrackInfo->setText(QCoreApplication::translate("qsessionframe", "Song Info", nullptr));
        label_3->setText(QCoreApplication::translate("qsessionframe", "(free formatted plain text, carriage returns allowed)", nullptr));
        labelCharsRemaining->setText(QCoreApplication::translate("qsessionframe", "Characters remaining", nullptr));
        labelCharactersRemaining->setText(QCoreApplication::translate("qsessionframe", "1024", nullptr));
        pushButtonSaveInfo->setText(QCoreApplication::translate("qsessionframe", "Save Info", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxTrackNumber->setToolTip(QCoreApplication::translate("qsessionframe", "Changes the current track number, ranging\n"
"from 0 to the highest pattern.  Then, if\n"
"any Meta Text is present in that pattern,\n"
"then the first one is shown.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("qsessionframe", "Last Directory", nullptr));
        lineEditLastUsedDir->setText(QCoreApplication::translate("qsessionframe", "Last Used Directory", nullptr));
        lineEditLastUsedDir->setPlaceholderText(QCoreApplication::translate("qsessionframe", "N/A", nullptr));
        label_4->setText(QCoreApplication::translate("qsessionframe", "Song Path", nullptr));
        label_5->setText(QCoreApplication::translate("qsessionframe", "Pattern  No.", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonLogFileClear->setToolTip(QCoreApplication::translate("qsessionframe", "Clear the log file to allow logging messages\n"
"to the console. Must exit the application and\n"
"start it again to have it take effect. No easy\n"
"way to undo rerouting standard I/O to file.", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonLogFileClear->setText(QCoreApplication::translate("qsessionframe", "Clear", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qsessionframe: public Ui_qsessionframe {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSESSIONFRAME_H
